@@ -722,6 +722,16 @@ class Query(object):
             else:
                 con = args[0]
         else:
+            if len(args) == 0 and len(kwargs) == 1:
+                k, v = kwargs.items()[0]
+                d = {"path": k}
+                if v in constraints.UnaryConstraint.OPS:
+                    d["op"] = v
+                else:
+                    d["op"] = "="
+                    d["value"] = v
+                kwargs = d
+
             con = self.constraint_factory.make_constraint(*args, **kwargs)
 
         con.path = self.prefix_path(con.path)
