@@ -78,7 +78,7 @@ class Registry(object, UserDict.DictMixin):
             process(gene)
 
     This class is meant to aid with interoperation between
-    mines by allowing them to discover one-another, and 
+    mines by allowing them to discover one-another, and
     allow users to always have correct connection information.
     """
 
@@ -108,7 +108,7 @@ class Registry(object, UserDict.DictMixin):
     def __setitem__(self, name, item):
         raise NotImplementedError("You cannot add items to a registry")
 
-    def __delitem__(self, name): 
+    def __delitem__(self, name):
         raise NotImplementedError("You cannot remove items from a registry")
 
     def keys(self):
@@ -151,7 +151,7 @@ class Service(object):
       for row in in_both:
         do_something_with(row)
         ...
-      
+
     OVERVIEW
     --------
     The two methods the user will be most concerned with are:
@@ -163,8 +163,8 @@ class Service(object):
 
     TERMINOLOGY
     -----------
-    X{Query} is the term for an arbitrarily complex structured request for 
-    data from the webservice. The user is responsible for specifying the 
+    X{Query} is the term for an arbitrarily complex structured request for
+    data from the webservice. The user is responsible for specifying the
     structure that determines what records are returned, and what information
     about each record is provided.
 
@@ -225,8 +225,8 @@ class Service(object):
         There are two alternative authentication systems supported by InterMine
         webservices. The first is username and password authentication, which
         is supported by all webservices. Newer webservices (version 6+)
-        also support API access token authentication, which is the recommended 
-        system to use. Token access is more secure as you will never have 
+        also support API access token authentication, which is the recommended
+        system to use. Token access is more secure as you will never have
         to transmit your username or password, and the token can be easily changed
         or disabled without changing your webapp login details.
 
@@ -269,13 +269,13 @@ class Service(object):
 
     # Delegated list methods
 
-    LIST_MANAGER_METHODS = frozenset(["get_list", "get_all_lists", 
+    LIST_MANAGER_METHODS = frozenset(["get_list", "get_all_lists",
         "get_all_list_names",
         "create_list", "get_list_count", "delete_lists", "l"])
 
     def __getattribute__(self, name):
         return object.__getattribute__(self, name)
-    
+
     def __getattr__(self, name):
         if name in self.LIST_MANAGER_METHODS:
             method = getattr(self._list_manager, name)
@@ -283,7 +283,7 @@ class Service(object):
         raise AttributeError("Could not find " + name)
 
     def __del__(self):
-        try: 
+        try:
             self._list_manager.delete_temporary_lists()
         except ReferenceError:
             pass
@@ -295,7 +295,7 @@ class Service(object):
         ==============================
 
         The version specifies what capabilities a
-        specific webservice provides. The most current 
+        specific webservice provides. The most current
         version is 3
 
         may raise ServiceError: if the version cannot be fetched
@@ -314,7 +314,7 @@ class Service(object):
         """Resolve the path to optional services"""
         url = self.root + self.SERVICE_RESOLUTION_PATH + variant
         return self.opener.open(url).read()
-    
+
     @property
     def release(self):
         """
@@ -326,7 +326,7 @@ class Service(object):
         The release is an arbitrary string used to distinguish
         releases of the datawarehouse. This usually coincides
         with updates to the data contained within. While a string,
-        releases usually sort in ascending order of recentness 
+        releases usually sort in ascending order of recentness
         (eg: "release-26", "release-27", "release-28"). They can also
         have less machine readable meanings (eg: "beta")
 
@@ -358,7 +358,7 @@ class Service(object):
         Construct a new Query object with the given columns selected.
         =============================================================
 
-        As new_query, except that instead of a root class, a list of 
+        As new_query, except that instead of a root class, a list of
         output column expressions are passed instead.
         """
         if len(columns) == 1 and not columns[0].endswith("*"):
@@ -375,9 +375,9 @@ class Service(object):
 
         Tries to retrieve a template of the given name
         from the webservice. If you are trying to fetch
-        a private template (ie. one you made yourself 
+        a private template (ie. one you made yourself
         and is not available to others) then you may need to authenticate
-        
+
         @see: L{intermine.webservice.Service.__init__}
 
         @param name: the template's name
@@ -391,12 +391,12 @@ class Service(object):
         try:
             t = self.templates[name]
         except KeyError:
-            raise ServiceError("There is no template called '" 
+            raise ServiceError("There is no template called '"
                 + name + "' at this service")
         if not isinstance(t, Template):
             t = Template.from_xml(t, self.model, self)
             self.templates[name] = t
-        return t 
+        return t
 
     @property
     def templates(self):
@@ -408,7 +408,7 @@ class Service(object):
 
         For efficiency's sake, Templates are not parsed until
         they are required, and until then they are stored as XML
-        strings. It is recommended that in most cases you would want 
+        strings. It is recommended that in most cases you would want
         to use L{Service.get_template}.
 
         You can use this property however to test for template existence though::
@@ -443,7 +443,7 @@ class Service(object):
 
         This is used when constructing queries to provide them
         with information on the structure of the data model
-        they are accessing. You are very unlikely to want to 
+        they are accessing. You are very unlikely to want to
         access this object directly.
 
         raises ModelParseError: if the model cannot be read
@@ -462,7 +462,7 @@ class Service(object):
         ===============================================
 
         This method is called internally by the query objects
-        when they are called to get results. You will not 
+        when they are called to get results. You will not
         normally need to call it directly
 
         @param path: The resource path (eg: "/query/results")
@@ -492,13 +492,13 @@ class ResultObject(object):
         ...    print gene.symbol
         ...    print map(lambda x: x.name, gene.pathways)
 
-    All objects will have "id" and "type" properties. The type refers to the 
+    All objects will have "id" and "type" properties. The type refers to the
     actual type of this object: if it is a subclass of the one requested, the
     subclass name will be returned. The "id" refers to the internal database id
     of the object, and is a guarantor of object identity.
 
     """
-    
+
     def __init__(self, data, cld):
         self._data = data
         self._cld = cld
@@ -522,9 +522,15 @@ class ResultObject(object):
             else:
                 data = self._fetch_reference(fld)
             if isinstance(fld, Collection):
-                attr = map(lambda x: ResultObject(x, fld.type_class), data)
-            else: 
-                attr = ResultObject(data, fld.type_class)
+                if data is None:
+                    attr = []
+                else:
+                    attr = map(lambda x: ResultObject(x, fld.type_class), data)
+            else:
+                if data is None:
+                    attr = None
+                else:
+                    attr = ResultObject(data, fld.type_class)
         else:
             raise WebserviceError("Inconsistent model - This should never happen")
         self._attr_cache[name] = attr
@@ -535,7 +541,8 @@ class ResultObject(object):
         q.select("id", fld.name + ".*")
         q.where("id", "=", self._data["objectId"])
         q.outerjoin(fld.name)
-        return q.first()._data[fld.name]
+        r = q.first()
+        return r._data[fld.name] if fld.name in r._data else None
 
 
 class ResultRow(object):
@@ -543,13 +550,13 @@ class ResultRow(object):
     An object for representing a row of data received back from the server.
     =======================================================================
 
-    ResultRows provide access to the fields of the row through index lookup. However, 
-    for convenience both list indexes and dictionary keys can be used. So the 
+    ResultRows provide access to the fields of the row through index lookup. However,
+    for convenience both list indexes and dictionary keys can be used. So the
     following all work:
 
         >>> # Assuming the view is "Gene.symbol", "Gene.organism.name":
         >>> row[0] == row["symbol"] == row["Gene.symbol"]
-        ... True 
+        ... True
 
     """
 
@@ -632,7 +639,7 @@ class ResultRow(object):
             self._get_index_for(key)
             return True
         except KeyError:
-           return False 
+           return False
 
 class TableResultRow(ResultRow):
     """
@@ -660,11 +667,11 @@ class ResultIterator(object):
 
     These objects handle the iteration over results
     in the formats requested by the user. They are responsible
-    for generating an appropriate parser, 
+    for generating an appropriate parser,
     connecting the parser to the results, and delegating
     iteration appropriately.
     """
-    
+
     PARSED_FORMATS = frozenset(["rr", "list", "dict"])
     STRING_FORMATS = frozenset(["tsv", "csv", "count"])
     JSON_FORMATS = frozenset(["jsonrows", "jsonobjects", "json"])
@@ -675,7 +682,7 @@ class ResultIterator(object):
         Constructor
         ===========
 
-        Services are responsible for getting result iterators. You will 
+        Services are responsible for getting result iterators. You will
         not need to create one manually.
 
         @param root: The root path (eg: "http://www.flymine.org/query/service")
@@ -697,7 +704,7 @@ class ResultIterator(object):
         if rowformat.startswith("object"): # Accept "object", "objects", "objectformat", etc...
             rowformat = "jsonobjects" # these are synonymous
         if rowformat not in self.ROW_FORMATS:
-            raise ValueError("'%s' is not one of the valid row formats (%s)" 
+            raise ValueError("'%s' is not one of the valid row formats (%s)"
                     % (rowformat, repr(list(self.ROW_FORMATS))))
 
         self.row = ResultRow if service.version >= 8 else TableResultRow
@@ -761,7 +768,7 @@ class ResultIterator(object):
     def next(self):
         """
         Returns the next row, in the appropriate format
-        
+
         @rtype: whatever the rowformat was determined to be
         """
         if self._it is None:
@@ -827,7 +834,7 @@ class JSONIterator(object):
         self.footer = ""
         self.parse_header()
         self._is_finished = False
-    
+
     def __iter__(self):
         return self
 
@@ -854,7 +861,7 @@ class JSONIterator(object):
 
         The footer containts information as to whether the result
         set was successfully transferred in its entirety. This
-        method makes sure we don't silently accept an 
+        method makes sure we don't silently accept an
         incomplete result set.
 
         @raise WebserviceError: if the footer indicates there was an error
@@ -889,8 +896,8 @@ class JSONIterator(object):
                     try:
                         row = json.loads(line)
                     except json.decoder.JSONDecodeError, e:
-                        raise WebserviceError("Error parsing line from results: '" 
-                                + line + "' - " + str(e)) 
+                        raise WebserviceError("Error parsing line from results: '"
+                                + line + "' - " + str(e))
                     next_row = self.parser(row)
         except StopIteration:
             raise WebserviceError("Connection interrupted")
@@ -930,7 +937,7 @@ class InterMineURLOpener(urllib.FancyURLopener):
             self.addheader("Authorization", base64string)
             self.plain_post_header["Authorization"] = base64string
             self.using_authentication = True
-        else: 
+        else:
             self.using_authentication = False
 
     def post_plain_text(self, url, body):
@@ -947,7 +954,7 @@ class InterMineURLOpener(urllib.FancyURLopener):
 
     def open(self, url, data=None):
         url = self.prepare_url(url)
-        return urllib.FancyURLopener.open(self, url, data) 
+        return urllib.FancyURLopener.open(self, url, data)
 
     def prepare_url(self, url):
         if self.token:
@@ -1041,7 +1048,7 @@ class InterMineURLOpener(urllib.FancyURLopener):
         Handle 404 HTTP errors, attempting to return informative error messages
         =======================================================================
 
-        404 errors indicate that the requested resource does not exist - usually 
+        404 errors indicate that the requested resource does not exist - usually
         a template that is not longer available.
 
         @raise WebserviceError: in all circumstances
@@ -1060,7 +1067,7 @@ class InterMineURLOpener(urllib.FancyURLopener):
         =======================================================================
 
         500 errors indicate that the server borked during the request - ie: it wasn't
-        our fault. 
+        our fault.
 
         @raise WebserviceError: in all circumstances
 
